getInitialMessage method
Get the initial message that caused the app to open.
Returns the notification payload if the app was terminated (cold start) and the user tapped on a notification. Returns null if the app was not launched by tapping a notification.
Implementation
Future<Map<String, dynamic>?> getInitialMessage() {
throw UnimplementedError('getInitialMessage() has not been implemented.');
}